
.. image:: https://img.shields.io/travis/com/sizmailov/amber-runner/master.svg?logo=travis
    :alt: master status
    :target: https://travis-ci.com/sizmailov/amber-runner

.. image:: https://img.shields.io/pypi/v/amber-runner.svg?logo=PyPI&logoColor=white
     :alt: pypi package
     :target: https://pypi.org/project/amber-runner/

.. image:: https://codecov.io/gh/sizmailov/amber-runner/branch/master/graph/badge.svg
  :alt: coverage
  :target: https://codecov.io/gh/sizmailov/amber-runner